@@ -58,8 +58,8 @@ test_that(
       method = "class",
       case_weights = y_weights
     )
-    rpart_optimization$predict_args <- list(type = "class")
-    rpart_optimization$performance_metric <- metric("bacc")
+    rpart_optimization$predict_args <- list(type = "prob")
+    rpart_optimization$performance_metric <- metric("multiclass.Brier")
     rpart_optimization$return_models <- TRUE
 
     # set data
@@ -194,7 +194,7 @@ test_that(
     rpart_optimization$optim_args <- optim_args
 
     rpart_optimization$predict_args <- list(type = "class")
-    rpart_optimization$performance_metric <- metric("bacc")
+    rpart_optimization$performance_metric <- metric("MMCE")
 
     # set data
     rpart_optimization$set_data(
@@ -233,7 +233,7 @@ test_that(
     rpart_optimization$split_type <- "stratified"
 
     rpart_optimization$predict_args <- list(type = "class")
-    rpart_optimization$performance_metric <- metric("bacc")
+    rpart_optimization$performance_metric <- metric("MMCE")
 
     # set data
     rpart_optimization$set_data(
